@@ -7,10 +7,11 @@ from typing import Optional, Sequence
 from fastapi import FastAPI
 
 from svc_infra.db.nosql.management import make_document_crud_schemas
-from svc_infra.db.nosql.mongo.client import close_mongo, init_mongo
+from svc_infra.db.nosql.mongo.client import close_mongo, get_db, init_mongo
 from svc_infra.db.nosql.repository import NoSqlRepository
 from svc_infra.db.nosql.resource import NoSqlResource
 from svc_infra.db.nosql.service import NoSqlService
+from svc_infra.db.nosql.utils import get_mongo_dbname_from_env
 
 from .crud_router import make_crud_router_plus_mongo
 from .health import make_mongo_health_router
@@ -22,8 +23,13 @@ def add_mongo_db(app: FastAPI, *, url: Optional[str] = None, dsn_env: str = "MON
 
         @asynccontextmanager
         async def lifespan(_app: FastAPI):
-            await init_mongo()
+            await init_mongo(url=url)  # explicit URL path
             try:
+                # assert after init
+                expected = get_mongo_dbname_from_env(required=False)
+                db = await anext(get_db())
+                if expected and db.name != expected:
+                    raise RuntimeError(f"Connected to Mongo DB '{db.name}', expected '{expected}'.")
                 yield
             finally:
                 await close_mongo()
@@ -36,7 +42,13 @@ def add_mongo_db(app: FastAPI, *, url: Optional[str] = None, dsn_env: str = "MON
         env_url = os.getenv(dsn_env)
         if not env_url:
             raise RuntimeError(f"Missing environment variable {dsn_env} for Mongo URL")
-        await init_mongo()
+        await init_mongo()  # uses env-driven MongoSettings
+
+        # assert AFTER init — prevents silent writes to the wrong DB
+        expected = get_mongo_dbname_from_env(required=False)
+        db = await anext(get_db())
+        if expected and db.name != expected:
+            raise RuntimeError(f"Connected to Mongo DB '{db.name}', expected '{expected}'.")
 
     @app.on_event("shutdown")
     async def _shutdown() -> None:  # noqa: ANN202
@@ -52,7 +64,7 @@ def add_mongo_health(
 def add_mongo_resources(app: FastAPI, resources: Sequence[NoSqlResource]) -> None:
     for r in resources:
         repo = NoSqlRepository(
-            collection_name=r.collection,
+            collection_name=r.resolved_collection(),
             id_field=r.id_field,
             soft_delete=r.soft_delete,
             soft_delete_field=r.soft_delete_field,
